@@ -1,6 +1,7 @@
 import asyncio
 import json
 import typing
+from asyncio import get_event_loop
 from contextvars import Context
 from inspect import Parameter
 from pathlib import Path
@@ -91,7 +92,7 @@ def nlu_get_languages(log_level: Text):
 @click.option(
     "-F",
     "--from-platform",
-    type=click.Choice(["dialogflow", "rasa", "csv"], case_sensitive=False),
+    type=click.Choice(["dialogflow", "rasa", "csv", "luis"], case_sensitive=False),
     required=True,
     help="From where to convert data from [dialogflow, rasa, csv]",
 )
@@ -190,6 +191,21 @@ def converter(
                 output_directory=Path(output_path),
                 dataset_type=DatasetTypes(data_type).value,
             )
+        elif from_platform == "luis":
+            from neuralspace.nlu.converters.luisconverter import (
+                LuisConverter,
+            )
+
+            converter = LuisConverter(
+                language=language,
+                entity_mapping=entity_mapping,
+                auto_tag_entities=auto_tag_entities,
+            )
+            converter.convert(
+                input_path=[Path(path) for path in input_path],
+                output_directory=Path(output_path),
+                dataset_type=DatasetTypes(data_type).value,
+            )
         else:
             from neuralspace.nlu.converters.csvconverter import CsvConverter
 
@@ -205,7 +221,7 @@ def converter(
                 output_directory=Path(output_path),
                 dataset_type=DatasetTypes(data_type).value,
             )
-        print_converted_data_inference(from_platform, output_path, converter)
+        print_converted_data_inference(from_platform, Path(output_path), converter)
     else:
         console.print(
             f"{ERROR} There is some error in the entity mapping you have given"
