@@ -17,6 +17,7 @@ from neuralspace.constants import (
     BOLD_START,
     BOOK,
     COMMON_HEADERS,
+    CONFIDENCE,
     COUNT,
     CROSS,
     DARK_ORANGE_END,
@@ -54,6 +55,7 @@ from neuralspace.constants import (
     neuralspace_url,
 )
 
+console = Console()
 logger = logging.getLogger("rich")
 console = Console()
 
@@ -337,12 +339,12 @@ def print_language_detection_response(text: Text, detected_languages: List[Dict]
     for language in detected_languages:
         if original_text_shown is False:
             table.add_row(
-                text, language["language"], str(round(float(language["confidence"]), 2))
+                text, language[LANGUAGE], str(round(float(language[CONFIDENCE]), 2))
             )
             original_text_shown = True
         else:
             table.add_row(
-                "", language["language"], str(round(float(language["confidence"]), 2))
+                "", language[LANGUAGE], str(round(float(language[CONFIDENCE]), 2))
             )
     console.print(table)
 
